@@ -20,13 +20,18 @@ __all__ = ['SoftTargetCrossEntropy', "soft_target_cross_entropy_loss"]
 
 
 class SoftTargetCrossEntropy(nn.Module):
+    """
+    Optimized for MixUpd
+    """
 
     def __init__(self):
         super(SoftTargetCrossEntropy, self).__init__()
 
     def forward(self, x: Dict, target: Tensor) -> Tensor:
         x = x[KEY_OUTPUT]
-        target = F.one_hot(target, num_classes=x.shape[1])
+        if len(target.shape) == 1:
+            target = F.one_hot(target, num_classes=x.shape[1])
+        # print(target.shape, F.log_softmax(x, dim=-1).shape)
 
         loss = torch.sum(-target * F.log_softmax(x, dim=-1), dim=-1)
         return loss.mean()
